==> unit-1.0.49-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractDownloadDialogOption.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractDownloadDialogOption<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _50_1_11903500967 _50_1_11903500967;
	public DownloadDialogOption._50_1_11903500967. Name name;
	public _51_1_01001280775 _51_1_01001280775;
	public DownloadDialogOption._51_1_01001280775. Options options;

    public AbstractDownloadDialogOption(B box) {
        super(box);
        id("DownloadDialogOption");
    }

    @Override
	public void init() {
		super.init();
		if (_50_1_11903500967 == null) _50_1_11903500967 = register(new _50_1_11903500967(box()).<_50_1_11903500967>id("a1769813299").owner(AbstractDownloadDialogOption.this));
		if (_50_1_11903500967 != null) name = _50_1_11903500967.name;
		if (_51_1_01001280775 == null) _51_1_01001280775 = register(new _51_1_01001280775(box()).<_51_1_01001280775>id("a_1986938386").owner(AbstractDownloadDialogOption.this));
		if (_51_1_01001280775 != null) options = _51_1_01001280775.options;
	}

	public class _50_1_11903500967 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public DownloadDialogOption._50_1_11903500967. Name name;

		public _50_1_11903500967(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (name == null) name = register(new Name(box()).<Name>id("a_783095790").owner(AbstractDownloadDialogOption.this));
		}

		public class Name extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public Name(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}

	public class _51_1_01001280775 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public DownloadDialogOption._51_1_01001280775. Options options;

		public _51_1_01001280775(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (options == null) options = register(new Options(box()).<Options>id("a582355576").owner(AbstractDownloadDialogOption.this));
		}

		public class Options extends io.intino.alexandria.ui.displays.components.SelectorComboBox<io.intino.alexandria.ui.displays.notifiers.SelectorComboBoxNotifier, B>  {

			public Options(B box) {
				super(box);
				_multipleSelection(false);
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}

==> unit-1.1.17-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractDownloadDialogOption.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractDownloadDialogOption<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _50_1_0478424155 _50_1_0478424155;
	public DownloadDialogOption._50_1_0478424155. Name name;
	public _51_1_01001280775 _51_1_01001280775;
	public DownloadDialogOption._51_1_01001280775. Options options;

    public AbstractDownloadDialogOption(B box) {
        super(box);
        id("DownloadDialogOption");
    }

    @Override
	public void init() {
		super.init();
		if (_50_1_0478424155 == null) _50_1_0478424155 = register(new _50_1_0478424155(box()).<_50_1_0478424155>id("a826932878").owner(AbstractDownloadDialogOption.this));
		if (_50_1_0478424155 != null) name = _50_1_0478424155.name;
		if (_51_1_01001280775 == null) _51_1_01001280775 = register(new _51_1_01001280775(box()).<_51_1_01001280775>id("a_1986938386").owner(AbstractDownloadDialogOption.this));
		if (_51_1_01001280775 != null) options = _51_1_01001280775.options;
	}

    @Override
    public void remove() {
        super.remove();
	    if (_50_1_0478424155 != null) _50_1_0478424155.unregister();
	    if (_51_1_01001280775 != null) _51_1_01001280775.unregister();
	}

	public class _50_1_0478424155 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public DownloadDialogOption._50_1_0478424155. Name name;

		public _50_1_0478424155(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (name == null) name = register(new Name(box()).<Name>id("a_783095790").owner(AbstractDownloadDialogOption.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (name != null) name.unregister();
		}

		public class Name extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

			public Name(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}
	}

	public class _51_1_01001280775 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public DownloadDialogOption._51_1_01001280775. Options options;

		public _51_1_01001280775(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (options == null) options = register(new Options(box()).<Options>id("a582355576").owner(AbstractDownloadDialogOption.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (options != null) options.unregister();
		}

		public class Options extends io.intino.alexandria.ui.displays.components.SelectorComboBox<io.intino.alexandria.ui.displays.notifiers.SelectorComboBoxNotifier, B>  {

			public Options(B box) {
				super(box);
				_multipleSelection(false);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}
	}
}
